@@ -1,8 +1,12 @@
 #!/bin/bash
 DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null && pwd )"
-echo "DIR=$DIR"
+
+echo " [XT::RELEASE::BEFORE] DIR=$DIR"
 cd "$DIR/../../"
 rm -rfv FASTX-*
+if [[ -e "META.yml" ]]; then
+ mv META.yml META.old
+fi
 if [[ -e "experimental" ]];
 then
 	mv experimental ../_build_fastx_reader_exp
